import { compile } from '@nativescript-vue/compiler';
import * as runtime from '@nativescript-vue/runtime';
import { warn, isKnownView, registerRuntimeCompiler } from '@nativescript-vue/runtime';
export * from '@nativescript-vue/runtime';
import { isString, NOOP } from '@vue/shared';

//
const compileCache = Object.create(null);
function compileToFunction(template, options) {
    if (!isString(template)) {
        (process.env.NODE_ENV !== 'production') && warn('invalid template option: ', template);
        return NOOP;
    }
    const key = template;
    const cached = compileCache[key];
    if (cached) {
        return cached;
    }
    const { code } = compile(template, {
        // at runtime - the registry should know about all elements, so we override the
        // isNativeTag function from our standalone compiler
        isNativeTag: tag => isKnownView(tag),
        hoistStatic: true,
        onError(err) {
            // todo
        },
        ...options
    });
    // console.log(code)
    // const render = () => {}
    const render = new Function('Vue', code)(runtime);
    return (compileCache[key] = render);
}
registerRuntimeCompiler(compileToFunction);

export { compileToFunction as compile };
